OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\"ディレクトリに書き込むことは出来ません！",
    "This can usually be fixed by giving the web server write access to the config directory." : "これは通常、Webサーバーにconfigディレクトリへの書き込み権限を与えることで解決できます。",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "しかし、config.phpファイルを読み取り専用にしたい場合は、オプションの \"config_is_read_only\"をtrueに設定してください。",
    "See %s" : "%s を閲覧",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "アプリケーション%1$sが存在しないか、このサーバと互換性のないバージョンがあります。apps ディレクトリを確認してください。",
    "Sample configuration detected" : "サンプル設定が見つかりました。",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "サンプル設定がコピーされてそのままです。このままではインストールが失敗し、サポート対象外になります。config.phpを変更する前にドキュメントを確認してください。",
    "The page could not be found on the server." : "ページがサーバー上に見つかりませんでした。",
    "%s email verification" : "%sメールによる確認",
    "Email verification" : "メールによる確認",
    "Click the following button to confirm your email." : "下記のボタンをクリックして、メールを確認してください。",
    "Click the following link to confirm your email." : "下記のリンクをクリックして、メールを確認してください。",
    "Confirm your email" : "メールを確認",
    "Other activities" : "その他のアクティビティ",
    "%1$s and %2$s" : "%1$s と %2$s",
    "%1$s, %2$s and %3$s" : "%1$s と %2$s、%3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s と %2$s、%3$s、%4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s と %2$s、%3$s、%4$s、%5$s",
    "Education bundle" : "教育向けバンドル",
    "Enterprise bundle" : "エンタープライズ バンドル",
    "Groupware bundle" : "グループウェア バンドル",
    "Hub bundle" : "Hubバンドル",
    "Public sector bundle" : "公共部門バンドル",
    "Social sharing bundle" : "SNS バンドル",
    "PHP %s or higher is required." : "PHP %s 以上が必要です。",
    "PHP with a version lower than %s is required." : "%s 以前のバージョンのPHPが必要です。",
    "%sbit or higher PHP required." : "%sbit 以上の新しいバージョンのPHPが必要です。",
    "The following architectures are supported: %s" : "次のアーキテクチャをサポートしています: %s",
    "The following databases are supported: %s" : "次のデータベースをサポートしています: %s",
    "The command line tool %s could not be found" : "コマンド '%s' は見つかりませんでした。",
    "The library %s is not available." : " %s ライブラリーが利用できません。",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$sライブラリーは、%2$sよりも新しいバージョンが必要です。利用可能なバージョンは、 %3$sです。",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%1$s ライブラリーは、%2$s よりも古いバージョンが必要です。利用可能なバージョンは、%3$s です。",
    "The following platforms are supported: %s" : "次のプラットフォームをサポートしています: %s",
    "Server version %s or higher is required." : "サーバーの %s よりも高いバージョンが必要です。",
    "Server version %s or lower is required." : "サーバーの %s よりも低いバージョンが必要です。",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "この設定にアクセスするには、ログインしたアカウントが管理者、サブ管理者、または特別な権利を持っている必要があります。",
    "Your current IP address doesn't allow you to perform admin actions" : "現在のIPアドレスでは管理アクションを実行できません",
    "Logged in account must be an admin or sub admin" : "ログインアカウントは管理者またはサブ管理者である必要があります",
    "Logged in account must be an admin" : "ログインアカウントは管理者である必要があります",
    "Wiping of device %s has started" : "端末%sのワイプを開始しました。",
    "Wiping of device »%s« has started" : "端末»%s«のワイプを開始しました。",
    "»%s« started remote wipe" : "»%s«がリモートワイプを開始しました",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "端末またはアプリケーション»%s«がリモートワイプ処理を開始しました。 プロセスの完了時、電子メールを受信します",
    "Wiping of device %s has finished" : "端末%sのワイプが完了しました",
    "Wiping of device »%s« has finished" : "端末»%s«のワイプが完了しました",
    "»%s« finished remote wipe" : "»%s«のリモートワイプが完了しました",
    "Device or application »%s« has finished the remote wipe process." : "端末またはアプリケーション»%s«のリモートワイプ処理が完了しました。 ",
    "Remote wipe started" : "リモートワイプを開始しました",
    "A remote wipe was started on device %s" : "端末%sでリモートワイプが開始されました",
    "Remote wipe finished" : "リモートワイプが完了しました",
    "The remote wipe on %s has finished" : "%sのリモートワイプが完了しました",
    "Authentication" : "認証",
    "Unknown filetype" : "不明なファイルタイプ",
    "Invalid image" : "無効な画像",
    "Avatar image is not square" : "アバター画像が正方形ではありません",
    "Files" : "ファイル",
    "View profile" : "プロフィールを表示",
    "same time" : "同時",
    "_%nh_::_%nh_" : ["%n時間"],
    "_%nm_::_%nm_" : ["%n分"],
    "%s ahead" : "%s先",
    "%s behind" : "%s遅れ",
    "Local time: %s" : "現地時間: %s",
    "today" : "今日",
    "tomorrow" : "明日",
    "yesterday" : "昨日",
    "_in %n day_::_in %n days_" : ["%n 日"],
    "_%n day ago_::_%n days ago_" : ["%n 日前"],
    "next month" : "来月",
    "last month" : "先月",
    "_in %n month_::_in %n months_" : ["%n ヶ月"],
    "_%n month ago_::_%n months ago_" : ["%n ヶ月前"],
    "next year" : "来年",
    "last year" : "去年",
    "_in %n year_::_in %n years_" : ["%n 年"],
    "_%n year ago_::_%n years ago_" : ["%n 年前"],
    "_in %n hour_::_in %n hours_" : ["%n 時間"],
    "_%n hour ago_::_%n hours ago_" : ["%n 時間前"],
    "_in %n minute_::_in %n minutes_" : ["%n 分"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分前"],
    "in a few seconds" : "数秒",
    "seconds ago" : "数秒前",
    "Empty file" : "空白のファイル",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
    "No file conversion providers available" : "ファイル変換プロバイダーは利用できません",
    "File is too large to convert" : "ファイルが大きすぎて変換できません",
    "Destination does not match conversion extension" : "変換先の拡張子が一致しません",
    "Could not convert file" : "ファイルを変換できませんでした",
    "Destination does not exist" : "宛先が存在しません",
    "Destination is not creatable" : "宛先は作成できません",
    "Dot files are not allowed" : "隠しファイルは許可されていません",
    "%1$s (renamed)" : "%1$s (リネーム済み)",
    "renamed file" : "リネーム済みファイル",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\"は禁止されているファイル名またはフォルダー名です。",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\"は、ファイル名やフォルダー名には使用できない接頭辞です。",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\"はファイル名やフォルダー名の中に入れることはできません。",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\"は禁止されているファイルタイプです。",
    "Filenames must not end with \"%1$s\"." : "ファイル名は \"%1$s\"で終了できません。",
    "Invalid parent path" : "無効な親パス",
    "File already exists" : "ファイルが既に存在します",
    "Invalid path" : "パスが無効",
    "Failed to create file from template" : "テンプレートからファイルを作成できませんでした",
    "Templates" : "テンプレート",
    "Storage %s cannot be moved" : "ストレージ%sは移動できません",
    "Moving a share (%s) into a shared folder is not allowed" : "共有(%s)を共有フォルダに移動することは許可されていません",
    "Moving a storage (%s) into a shared folder is not allowed" : "ストレージ(%s)を共有フォルダに移動することは許可されていません",
    "Moving a share (%s) into another share (%s) is not allowed" : "共有 (%s) を別の共有 (%s) に移動することは許可されていません",
    "Moving a share (%s) into another storage (%s) is not allowed" : "共有(%s)を別のストレージ(%s)に移動することは許可されていません",
    "Moving a storage (%s) into a share (%s) is not allowed" : "ストレージ(%s)を共有(%s)に移動することは許可されていません",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "ストレージ(%s)を別のストレージ(%s)に移動することは許可されていません。",
    "Path contains invalid segments" : "パスに無効なセグメントが含まれています",
    "Filename is a reserved word" : "ファイル名が予約された単語です",
    "Filename contains at least one invalid character" : "ファイル名に使用できない文字が含まれています",
    "Filename is too long" : "ファイル名が長すぎます",
    "Empty filename is not allowed" : "空のファイル名は許可されていません",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリ名 \"%s\"  がインストールできません。",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" アプリは、このバージョンのサーバーと互換性がないためインストールされませんでした。",
    "__language_name__" : "日本語 (Japanese)",
    "This is an automatically sent email, please do not reply." : "これは自動的に生成されたメールです。返信しないでください。",
    "Help & privacy" : "ヘルプとプライバシー",
    "Appearance and accessibility" : "外観とアクセシビリティ",
    "Apps" : "アプリ",
    "Personal settings" : "個人設定",
    "Administration settings" : "管理者設定",
    "Settings" : "設定",
    "Log out" : "ログアウト",
    "Accounts" : "アカウント",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "Blueskyで%sを表示",
    "Email" : "メール",
    "Mail %s" : "メール %s",
    "Fediverse" : "フェディバース",
    "View %s on the fediverse" : "%sをフェディバース上で見る",
    "Phone" : "携帯",
    "Call %s" : "電話 %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Twitterで%sを表示",
    "Website" : "ウェブサイト",
    "Visit %s" : "訪問先 %s",
    "Address" : "アドレス",
    "Profile picture" : "プロフィールの写真",
    "About" : "詳細",
    "Display name" : "表示名",
    "Headline" : "見出し",
    "Organization" : "共同作業",
    "Role" : "ロール",
    "Pronouns" : "代名詞",
    "Unknown account" : "不明なアカウント",
    "Additional settings" : "追加設定",
    "Enter the database Login and name for %s" : "%s のデータベース名とログイン名を入力してください",
    "Enter the database Login for %s" : "%sのデータベースログイン名を入力してください",
    "Enter the database name for %s" : "%sのデータベース名を指定してください",
    "You cannot use dots in the database name %s" : "データベース名%sにドットを入れることはできません",
    "MySQL Login and/or password not valid" : "MySQLのログイン名またはパスワードが有効ではありません",
    "You need to enter details of an existing account." : "既存のアカウントの詳細を入力してください。",
    "Oracle connection could not be established" : "Oracleへの接続が確立できませんでした。",
    "Oracle Login and/or password not valid" : "Oracleのログイン名またはパスワードが有効ではありません",
    "PostgreSQL Login and/or password not valid" : "PostgreSQLのログイン名またはパスワードが有効ではありません",
    "macOS is not supported and %s will not work properly on this platform." : "macOS はサポートされておらず、%s はこのプラットフォームでは正常に動作しません。",
    "For the best results, please consider using a GNU/Linux server instead." : "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
    "Set an admin Login." : "管理者ログインを設定します。",
    "Set an admin password." : "管理者のパスワードを設定",
    "Cannot create or write into the data directory %s" : " データディレクトリ%sに作成、書き込みができません",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s のバックエンドの共有には、OCP\\Share_Backend インターフェースを実装しなければなりません。",
    "Sharing backend %s not found" : "共有バックエンド %s が見つかりません",
    "Sharing backend for %s not found" : "%s のための共有バックエンドが見つかりません",
    "%1$s shared %2$s with you" : "%1$s は %2$s をあなたと共有しました",
    "Open %s" : "%sを開く",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s さんが %2$s にノートを追加しました:",
    "%1$s shared %2$s with you and wants to add" : "%1$s さんが %2$s にノートを追加しました",
    "%s added a note to a file shared with you" : "%s があなたと共有しているファイルにノートを追加しました。",
    "Passwords are enforced for link and mail shares" : "リンクとメールの共有にパスワードが強制されます",
    "Share recipient is not a valid user" : "共有先が有効なユーザーではありません",
    "Share recipient is not a valid group" : "共有先が有効なグループではありません",
    "Share recipient should be empty" : "共有先は空にする必要があります",
    "Share recipient should not be empty" : "共有先は空にできません",
    "Share recipient is not a valid circle" : "共有先が有効なサークルではありません",
    "Unknown share type" : "不明な共有タイプ",
    "Share initiator must be set" : "共有イニシエータを設定する必要があります",
    "Cannot share with yourself" : "自分自身とは共有できません",
    "Shared path must be set" : "共有パスを設定する必要があります",
    "Shared path must be either a file or a folder" : "共有パスは、ファイルまたはフォルダのいずれかでなければなりません",
    "You cannot share your root folder" : "ルートルートフォルダーを共有することはできません",
    "You are not allowed to share %s" : "%s を共有することを許可されていません。",
    "Valid permissions are required for sharing" : "共有には有効な権限が必要です",
    "File shares cannot have create or delete permissions" : "ファイル共有に作成または削除の権限を設定することはできません",
    "Cannot increase permissions of %s" : "%sの権限を追加できません ",
    "Shares need at least read permissions" : "共有には少なくとも読み取り権限が必要です",
    "Files cannot be shared with delete permissions" : "削除権限付きでファイルを共有できません",
    "Files cannot be shared with create permissions" : "作成権限付きでファイルを共有できません",
    "Expiration date is in the past" : "有効期限が切れています",
    "Expiration date is enforced" : "有効期限は強制されています",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["%n 日以上先の有効期限は設定できません "],
    "Sharing is only allowed with group members" : "共有はグループメンバーにのみ許可されます",
    "Sharing %s failed, because this item is already shared with the account %s" : "このアイテム %s はすでにアカウント %s と共有されているため、共有に失敗しました",
    "Group sharing is now allowed" : "グループ共有が許可されました",
    "Sharing is only allowed within your own groups" : "共有は自分のグループ内でのみ許可されています",
    "Path is already shared with this group" : "パスはすでにこのグループで共有されています",
    "Link sharing is not allowed" : "リンクの共有は許可されていません",
    "Public upload is not allowed" : "公開アップロードは許可されていません",
    "You cannot share a folder that contains other shares" : "他の共有を含むフォルダーを共有することはできません",
    "Sharing is disabled" : "共有は無効になっています",
    "Sharing is disabled for you" : "共有は無効になっています",
    "Cannot share with the share owner" : "共有所有者と共有できません",
    "Share does not have a full ID" : "共有に完全なIDがありません",
    "Cannot change share type" : "共有タイプを変更できません",
    "Can only update recipient on user shares" : "ユーザー共有の受信者のみ更新可能",
    "Cannot enable sending the password by Talk with an empty password" : "空のパスワードでTalkによるパスワード送信を有効にできません",
    "Cannot enable sending the password by Talk without setting a new password" : "新しいパスワードを設定しないとTalkでパスワードを送信できません",
    "Cannot disable sending the password by Talk without setting a new password" : "新しいパスワードを設定しないとTalkによるパスワード送信を無効にできません",
    "Share provider does not support accepting" : "共有プロバイダは受け入れをサポートしていません",
    "Cannot change target of link share" : "リンク共有のターゲットを変更できません",
    "Invalid share recipient" : "無効な共有先",
    "Group \"%s\" does not exist" : "グループ \"%s\" は存在しません",
    "The requested share does not exist anymore" : "この共有はもう存在しません。",
    "The requested share comes from a disabled user" : "要求された共有は無効化されたユーザーからのものです。",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "登録可能なユーザー数の上限に達したため、ユーザーは作成されませんでした。詳細については通知をご確認ください。",
    "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
    "Input text" : "テキストを入力",
    "The input text" : "入力テキスト",
    "Cannot generate more than 12 images" : "12枚以上の画像を生成できません",
    "Cannot generate less than 1 image" : "1枚未満の画像を生成できません",
    "Sunday" : "日曜日",
    "Monday" : "月曜日",
    "Tuesday" : "火曜日",
    "Wednesday" : "水曜日",
    "Thursday" : "木曜日",
    "Friday" : "金曜日",
    "Saturday" : "土曜日",
    "Sun." : "日",
    "Mon." : "月",
    "Tue." : "火",
    "Wed." : "水",
    "Thu." : "木",
    "Fri." : "金",
    "Sat." : "土",
    "Su" : "日",
    "Mo" : "月",
    "Tu" : "火",
    "We" : "水",
    "Th" : "木",
    "Fr" : "金",
    "Sa" : "土",
    "January" : "1月",
    "February" : "2月",
    "March" : "3月",
    "April" : "4月",
    "May" : "5月",
    "June" : "6月",
    "July" : "7月",
    "August" : "8月",
    "September" : "9月",
    "October" : "10月",
    "November" : "11月",
    "December" : "12月",
    "Jan." : "1月",
    "Feb." : "2月",
    "Mar." : "3月",
    "Apr." : "4月",
    "May." : "5月",
    "Jun." : "6月",
    "Jul." : "7月",
    "Aug." : "8月",
    "Sep." : "9月",
    "Oct." : "10月",
    "Nov." : "11月",
    "Dec." : "12月",
    "A valid password must be provided" : "有効なパスワードを指定する必要があります",
    "The Login is already being used" : "ログイン名は既に使用されています",
    "Could not create account" : "アカウントを作成できませんでした",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "ログイン名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", スペース, \"_.@-'\"",
    "A valid Login must be provided" : "ログイン名を提供する必要があります",
    "Login contains whitespace at the beginning or at the end" : "ログイン名の最初か最後に空白が含まれています",
    "Login must not consist of dots only" : "ログイン名はドットのみで構成されてはいけません",
    "Username is too long" : "ユーザー名が長すぎます",
    "Login is invalid because files already exist for this user" : "このユーザのファイルが既に存在するため、このログイン名は使用できません",
    "Account disabled" : "アカウントは無効",
    "Login canceled by app" : "アプリによりログインが中止されました",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "次の依存関係を満たしていないため、アプリ \"%1$s\" をインストールできません: %2$s",
    "a safe home for all your data" : "すべてのデータを安全に保管します",
    "Application is not enabled" : "アプリケーションは無効です",
    "Authentication error" : "認証エラー",
    "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "データベースドライバー (sqlite, mysql, postgresql) がインストールされていません。",
    "Cannot write into \"config\" directory." : "\"config\" ディレクトリに書き込みできません",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "これは通常、Webサーバーの configディレクトリ に書き込み権限を与えることで解決できます。%s を見てください",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "またはconfig.phpファイルを読み取り専用にしたい場合は、オプション \"config_is_read_only\"をtrueに設定してください。 詳しくは%sを確認してください。",
    "Cannot create \"data\" directory." : "dataディレクトリを作成できません。",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "これは通常、ウェブサーバーにルートディレクトリへの書き込み権限を与えることで解決できます。詳しくは%sを確認してください。",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Webサーバーのルートディレクトリに書き込み権限パーミッションが必要です。詳しくは%sを確認してください。",
    "Your data directory is not writable." : "データディレクトリに書き込み権がありません",
    "Setting locale to %s failed." : "ロケールを %s に設定できませんでした",
    "Please install one of these locales on your system and restart your web server." : "これらのロケールのうちいずれかをシステムにインストールし、Webサーバーを再起動してください。",
    "PHP module %s not installed." : "PHP のモジュールの %s がインストールされていません。",
    "Please ask your server administrator to install the module." : "サーバー管理者にモジュールのインストールを依頼してください。",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP設定の\"%s\"が \"%s\"に設定されていません",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini のこの設定を調整して、再度 Nextcloudを起動してください。",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHPでインラインドキュメントブロックを取り除く設定になっています。これによりコアアプリで利用できないものがいくつかあります。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "これは、Zend OPcacheやeAccelerator 等のキャッシュ/アクセラレーターが原因かもしれません。",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP モジュールはインストールされていますが、まだ一覧に表示されていますか？",
    "Please ask your server administrator to restart the web server." : "サーバー管理者にWebサーバーを再起動するよう依頼してください。",
    "The required %s config variable is not configured in the config.php file." : "必要な %s 構成変数が config.php ファイルに設定されていません。",
    "Please ask your server administrator to check the Nextcloud configuration." : "サーバー管理者にNextcloud構成を確認するように依頼してください。",
    "Your data directory is readable by other people." : "あなたのデータディレクトリは他の人が読み取ることができます",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "ディレクトリが他人から見えないように、パーミッションを 0770 に変更してください。",
    "Your data directory must be an absolute path." : "データディレクトリは、絶対パスにする必要があります",
    "Check the value of \"datadirectory\" in your configuration." : "設定ファイル内の \"datadirectory\" の値を確認してください。",
    "Your data directory is invalid." : "データディレクトリが無効です",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "データディレクトリのルートに\"%1$s\"というファイルがあることを確認します。内容は次のようになります:\"%2$s\"",
    "Action \"%s\" not supported or implemented." : "アクション「%s」は対応していないか、実装されていません。",
    "Authentication failed, wrong token or provider ID given" : "認証できませんでした。トークンまたはプロバイダーIDが間違っています",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "要求を完了するためのパラメータがありません。欠落したパラメータ:「%s」",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID｢%1$s｣はクラウドフェデレーションプロバイダー｢%2$s｣によって既に使用されています",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ID: \"%s\"のクラウドフェデレーションプロバイダーは存在しません。",
    "Could not obtain lock type %d on \"%s\"." : "\"%s\" で %d タイプのロックを取得できませんでした。",
    "Storage unauthorized. %s" : "権限のないストレージです。 %s",
    "Storage incomplete configuration. %s" : "設定が未完了のストレージです。 %s",
    "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
    "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "このチェックを実行させるには、Webサーバーが自分自身に接続できることを確認しなければならない。そのため、少なくとも一つの `trusted_domains` または `overwrite.cli.url` を解決して接続できなければなりません。この失敗は、サーバ側のDNSの不一致やアウトバウンドファイアウォールルールの結果かもしれません。",
    "Analyze images" : "画像を分析する",
    "Ask a question about the given images." : "与えられた画像について質問してください。",
    "Images" : "画像",
    "Images to ask a question about" : "質問したい画像",
    "Question" : "質問",
    "What to ask about the images." : "画像について質問する。",
    "Generated response" : "生成された応答",
    "The answer to the question" : "質問への回答",
    "Audio chat" : "音声チャット",
    "Voice chat with the assistant" : "アシスタントとの音声チャット",
    "System prompt" : "システムプロンプト",
    "Define rules and assumptions that the assistant should follow during the conversation." : "会話中にアシスタントが従うべきルールと前提条件を定義します。",
    "Chat voice message" : "チャット音声メッセージ",
    "Describe a task that you want the assistant to do or ask a question." : "アシスタントに実行してほしいタスクを説明するか質問を投げかけてください。",
    "Chat history" : "チャット履歴",
    "The history of chat messages before the current message, starting with a message by the user." : "現在のメッセージ以前に送信されたチャットメッセージの履歴で、ユーザーが送信したメッセージから始まるもの。",
    "Input transcript" : "文字起こしを入力",
    "Transcription of the audio input" : "音声入力の文字起こし",
    "Response voice message" : "応答音声メッセージ",
    "The generated voice response as part of the conversation" : "会話の一部として生成された音声応答",
    "Output transcript" : "文字起こしを出力",
    "Transcription of the audio output" : "音声出力の文字起こし",
    "Transcribe audio" : "音声の書き起こし",
    "Transcribe the things said in an audio" : "音声で言ったことを書き起こす",
    "Audio input" : "音声入力",
    "The audio to transcribe" : "文字起こしする音声",
    "Transcription" : "書き起こし",
    "The transcribed text" : "書き起こされたテキスト",
    "Chat by voice with an agent" : "エージェントと音声でチャットする",
    "Describe a task that you want the agent to do or ask a question." : "エージェントに実行してほしいタスクを説明するか質問を投げかけてください。エージェントと音声でチャットできます。",
    "Confirmation" : "確認",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "以前に要求されたアクションを承認するかどうか： 0なら拒否、1なら承認。",
    "Conversation token" : "会話トークン",
    "A token representing the conversation." : "会話を表すトークン。",
    "The new conversation token" : "新しい会話トークン",
    "Send this along with the next interaction." : "次の交流と一緒にこれを送る。",
    "Requested actions by the agent" : "エージェントが要求するアクション",
    "Actions that the agent would like to carry out in JSON format." : "エージェントが JSON 形式で実行したいアクション。",
    "Chat with an agent" : "エージェントとチャット",
    "Chat message" : "チャットメッセージ",
    "A chat message to send to the agent." : "エージェントに送信するチャットメッセージ。",
    "The response from the chat model." : "チャットモデルからの応答。",
    "Context write" : "コンテキストを書く",
    "Writes text in a given style based on the provided source material." : "提供されたソース資料に基づいて、指定されたスタイルでテキストを作成します。",
    "Writing style" : "文体",
    "Demonstrate a writing style that you would like to immitate" : "真似したい文章の書き方を示す",
    "Source material" : "素材",
    "The content that would like to be rewritten in the new writing style" : "新しい書き方で書き直したい内容",
    "Generated text" : "生成されたテキスト",
    "The generated text with content from the source material in the given style" : "指定されたスタイルのソースマテリアルのコンテンツを含む生成テキスト",
    "Emoji generator" : "絵文字ジェネレーター",
    "Takes text and generates a representative emoji for it." : "テキストを受け取り、それを表す絵文字を生成します。",
    "The text to generate an emoji for" : "絵文字を生成するテキスト",
    "Generated emoji" : "生成された絵文字",
    "The generated emoji based on the input text" : "入力テキストに基づいて生成された絵文字",
    "Optical character recognition" : "OCR",
    "Extract text from files like images or PDFs" : "画像やPDFのようなファイルからテキストを抽出する",
    "Input files" : "入力ファイル",
    "The files to extract text from" : "テキストを抽出するファイル",
    "Output texts" : "出力テキスト",
    "The texts that were extracted from the files" : "ファイルから抽出されたテキスト",
    "Generate image" : "画像生成",
    "Generate an image from a text prompt" : "テキストプロンプトから画像を生成する",
    "Prompt" : "プロンプト",
    "Describe the image you want to generate" : "生成する画像を記述します",
    "Number of images" : "画像の枚数",
    "How many images to generate" : "生成する画像の数",
    "Output images" : "出力画像",
    "The generated images" : "生成された画像",
    "Generate speech" : "スピーチの生成",
    "Generate speech from a transcript" : "原稿からスピーチを生成する",
    "Write transcript that you want the assistant to generate speech from" : "アシスタントに音声を生成させたい原稿を書きます",
    "Output speech" : "スピーチの出力",
    "The generated speech" : "生成されたスピーチ",
    "Free text to text prompt" : "フリーテキストからテキストへのプロンプト",
    "Runs an arbitrary prompt through a language model that returns a reply" : "応答を返す言語モデルを通じて任意のプロンプトを実行します",
    "Describe a task that you want the assistant to do or ask a question" : "アシスタントに実行してほしいタスクまたは質問を記述します",
    "Generated reply" : "生成された返信",
    "The generated text from the assistant" : "アシスタントから生成されたテキスト",
    "Change Tone" : "トーンを変更",
    "Change the tone of a piece of text." : "文章のトーンを変更する。",
    "Write a text that you want the assistant to rewrite in another tone." : "アシスタントに別のトーンで書き直してもらいたい文章を書く。",
    "Desired tone" : "希望するトーン",
    "In which tone should your text be rewritten?" : "どのトーンで書き直すべきか？",
    "The rewritten text in the desired tone, written by the assistant:" : "アシスタントが書き直した、希望するトーンの文章：",
    "Chat" : "チャット",
    "Chat with the assistant" : "アシスタントとチャット",
    "The history of chat messages before the current message, starting with a message by the user" : "ユーザーのメッセージから始まる、現在のメッセージより前のチャットメッセージの履歴",
    "Response message" : "応答メッセージ",
    "The generated response as part of the conversation" : "会話の一部として生成された応答",
    "Chat with tools" : "ツールでチャット",
    "Chat with the language model with tool calling support." : "ツール呼び出しサポートを使用して言語モデルとチャット。",
    "Tool message" : "ツールメッセージ",
    "The result of tool calls in the last interaction" : "直近のインタラクションにおけるツール呼び出しの結果",
    "Available tools" : "利用可能なツール",
    "The available tools in JSON format" : "JSON形式で利用可能なツール",
    "The response from the chat model" : "チャットモデルからの応答",
    "Tool calls" : "ツールコール",
    "Tools call instructions from the model in JSON format" : "JSON形式のモデルからのツール呼び出し命令",
    "Formalize text" : "テキストの形式化",
    "Takes a text and makes it sound more formal" : "テキストを使用して、よりフォーマルに聞こえるようにします",
    "Write a text that you want the assistant to formalize" : "アシスタントに形式化してもらいたいテキストを入力します",
    "Formalized text" : "形式化されたテキスト",
    "The formalized text" : "形式化されたテキスト",
    "Generate a headline" : "見出しの生成",
    "Generates a possible headline for a text." : "テキストの見出しの候補を生成",
    "Original text" : "原文",
    "The original text to generate a headline for" : "見出しを生成する元のテキスト",
    "The generated headline" : "生成された見出し",
    "Proofread" : "校正",
    "Proofreads a text and lists corrections" : "文章を校正し、訂正箇所をリストアップする",
    "Text" : "テキスト",
    "The text to proofread" : "校正するテキスト",
    "Corrections" : "修正",
    "The corrections that should be made in your text" : "テキストに加えるべき修正",
    "Reformulate text" : "テキストを書き直す",
    "Takes a text and reformulates it" : "テキストを受け取り、それを書き直す",
    "Write a text that you want the assistant to reformulate" : "アシスタントに書き直してもらいたいテキストを入力します",
    "Reformulated text" : "書き直されたテキスト",
    "The reformulated text, written by the assistant" : "アシスタントによって書かれた、書き直されたテキスト",
    "Simplify text" : "テキストの簡略化",
    "Takes a text and simplifies it" : "テキストを受け取って簡略化する",
    "Write a text that you want the assistant to simplify" : "アシスタントに簡略化してほしい文章を書く",
    "Simplified text" : "簡略化されたテキスト",
    "The simplified text" : "簡略化されたテキスト",
    "Summarize" : "要約する",
    "Summarizes a text" : "テキストを要約します",
    "The original text to summarize" : "要約する元のテキスト",
    "Summary" : "要約",
    "The generated summary" : "生成された要約",
    "Extract topics" : "トピックの抽出",
    "Extracts topics from a text and outputs them separated by commas" : "テキストからトピックを抽出し、カンマ区切りで出力します",
    "The original text to extract topics from" : "トピックを抽出する元のテキスト",
    "Topics" : "トピック",
    "The list of extracted topics" : "抽出されたトピックのリスト",
    "Translate" : "翻訳",
    "Translate text from one language to another" : "テキストをある言語から別の言語に翻訳する",
    "Origin text" : "原文",
    "The text to translate" : "翻訳するテキスト",
    "Origin language" : "元の言語",
    "The language of the origin text" : "元のテキストの言語",
    "Target language" : "訳文の言語",
    "The desired language to translate the origin text in" : "元のテキストを翻訳する言語",
    "Result" : "結果",
    "The translated text" : "翻訳されたテキスト",
    "Free prompt" : "任意のプロンプト",
    "Runs an arbitrary prompt through the language model." : "言語モデルを通じて任意のプロンプトを実行",
    "Generate headline" : "見出しの生成",
    "Summarizes text by reducing its length without losing key information." : "重要な情報を失わずにテキストの長さを要約して短縮する。",
    "Extracts topics from a text and outputs them separated by commas." : "テキストからトピックを抽出し、カンマ区切りで出力します。",
    "Organisation" : "組織",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
    "Login is too long" : "ログインが長すぎます",
    "Cannot write into \"apps\" directory." : "\"apps\" ディレクトリに書き込みができません",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "これは通常、Webサーバーにappsディレクトリへの書き込み権限を許可するか、構成ファイルでAppStoreを無効にすることで解決できます。",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>の値は <code>0</code>であるべきですが、<code>%s</code> に設定されています。",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "この問題を修正するには、php.ini ファイルの <code>mbstring.func_overload</code> を <code>0</code> に設定してください。"
},
"nplurals=1; plural=0;");
